from datetime import datetime
from datetime import timezone

import scrapy
from scrapy.crawler import CrawlerProcess

from ..controller import register_scraper
from ..scraper import BaseScraper
from snowscraper.helpers import string_to_datetime

QuickStartsURL = "https://quickstarts.snowflake.com/"


@register_scraper
class QuickstartScraper(BaseScraper, scrapy.Spider):
    name = "snowflakespider"

    def __init__(self, after, *args, **kwargs):
        super(QuickstartScraper, self).__init__(*args, **kwargs)
        self.data = {}
        self.after = after or datetime(1970, 1, 1, tzinfo=timezone.utc)

    def start_requests(self):
        yield scrapy.Request(url=QuickStartsURL, callback=self.parse)

    def scrape(self):
        print("Scraping Quickstarts")
        process = CrawlerProcess({"LOG_LEVEL": "ERROR"})
        process.crawl(QuickstartScraper, after=self.after)
        process.start()

    def parse(self, response):
        for card in response.css("card-sorter#cards > a.codelab-card"):
            updated = string_to_datetime(card.attrib["data-updated"])
            if updated > self.after:
                key = QuickStartsURL.rstrip("/") + card.attrib["href"]
                self.data[key] = {
                    "title": card.attrib["data-title"],
                    "updated": updated,
                    "tags": card.attrib["data-tags"],
                }
                # print(key, self.data[key])
                yield self.data[key]

    def transform(self):
        return self.data
